@@ -1,14 +1,15 @@
-import React, { FC } from 'react';
-import { LoginLayout, InnerBox } from '../Login/LoginLayout';
-import { ChangePassword } from './ChangePassword';
-import LoginCtrl from '../Login/LoginCtrl';
 import { GrafanaRouteComponentProps } from 'app/core/navigation/types';
 
+import LoginCtrl from '../Login/LoginCtrl';
+import { LoginLayout, InnerBox } from '../Login/LoginLayout';
+
+import { ChangePassword } from './ChangePassword';
+
 export interface Props extends GrafanaRouteComponentProps<{}, { code: string }> {}
 
-export const ChangePasswordPage: FC<Props> = (props) => {
+export const ChangePasswordPage = (props: Props) => {
   return (
-    <LoginLayout>
+    <LoginLayout isChangingPassword>
       <InnerBox>
         <LoginCtrl resetCode={props.queryParams.code}>
           {({ changePassword }) => <ChangePassword onSubmit={changePassword} />}
