@@ -12,7 +12,7 @@ interface Props {
 export function NavLandingPageCard({ description, text, url }: Props) {
   const styles = useStyles2(getStyles);
   return (
-    <Card className={styles.card} href={url}>
+    <Card noMargin className={styles.card} href={url}>
       <Card.Heading>{text}</Card.Heading>
       <Card.Description className={styles.description}>{description}</Card.Description>
     </Card>
@@ -21,7 +21,6 @@ export function NavLandingPageCard({ description, text, url }: Props) {
 
 const getStyles = (theme: GrafanaTheme2) => ({
   card: css({
-    marginBottom: 0,
     gridTemplateRows: '1fr 0 2fr',
   }),
   // Limit descriptions to 3 lines max before ellipsing
