@@ -1,8 +1,9 @@
 import { Suspense, useEffect, useLayoutEffect } from 'react';
 import { Navigate, useLocation } from 'react-router-dom-v5-compat';
 
-import { locationSearchToObject, navigationLogger, reportPageview } from '@grafana/runtime';
+import { config, locationSearchToObject, navigationLogger, reportPageview } from '@grafana/runtime';
 import { ErrorBoundary } from '@grafana/ui';
+import { isFrontendService } from 'app/core/utils/isFrontendService';
 
 import { useGrafana } from '../context/GrafanaContext';
 import { contextSrv } from '../services/context_srv';
@@ -44,7 +45,7 @@ export function GrafanaRoute(props: Props) {
   navigationLogger('GrafanaRoute', false, 'Rendered', props.route);
 
   return (
-    <ErrorBoundary dependencies={[props.route]}>
+    <ErrorBoundary boundaryName="grafana-route" dependencies={[props.route]}>
       {({ error, errorInfo }) => {
         if (error) {
           return <GrafanaRouteError error={error} errorInfo={errorInfo} />;
@@ -62,6 +63,17 @@ export function GrafanaRoute(props: Props) {
 
 export function GrafanaRouteWrapper({ route }: Pick<Props, 'route'>) {
   const location = useLocation();
+
+  // Perform login check in the frontend now
+  if (isFrontendService()) {
+    const routeRequiresSignin = !route.allowAnonymous && !config.anonymousEnabled;
+    if (routeRequiresSignin && !contextSrv.isSignedIn) {
+      contextSrv.setRedirectToUrl();
+
+      return <Navigate replace to="/login" />;
+    }
+  }
+
   const roles = route.roles ? route.roles() : [];
   if (roles?.length) {
     if (!roles.some((r: string) => contextSrv.hasRole(r))) {
