@@ -283,7 +283,7 @@ const DatasourceNotFound = ({ index, onUpdateDatasource, onRemoveQuery, model }:
   return (
     <EmptyQueryWrapper>
       <QueryOperationRow title={refId} draggable index={index} id={refId} isOpen collapsable={false}>
-        <Card>
+        <Card noMargin>
           <Card.Heading>
             <Trans i18nKey="alerting.datasource-not-found.this-datasource-has-been-removed">
               This datasource has been removed
