@@ -3,11 +3,17 @@ import { Checkbox } from '@grafana/ui';
 
 import { DashboardTreeHeaderProps, SelectionState } from '../types';
 
-export default function CheckboxHeaderCell({ isSelected, onAllSelectionChange }: DashboardTreeHeaderProps) {
+export default function CheckboxHeaderCell({
+  isSelected,
+  onAllSelectionChange,
+  permissions,
+}: DashboardTreeHeaderProps) {
   const state = isSelected?.('$all') ?? SelectionState.Unselected;
+  const isReadOnlyRepo = permissions?.isReadOnlyRepo;
 
   return (
     <Checkbox
+      disabled={isReadOnlyRepo}
       value={state === SelectionState.Selected}
       indeterminate={state === SelectionState.Mixed}
       aria-label={t('browse-dashboards.dashboards-tree.select-all-header-checkbox', 'Select all')}
