@@ -21,9 +21,10 @@ import {
   IntervalVariable,
   QueryVariable,
   SceneVariableSet,
+  SwitchVariable,
   TextBoxVariable,
 } from '@grafana/scenes';
-import { DataSourceRef, VariableRefresh } from '@grafana/schema';
+import { DataSourceRef, VariableHide, VariableRefresh } from '@grafana/schema';
 
 import { sceneVariablesSetToSchemaV2Variables, sceneVariablesSetToVariables } from './sceneVariablesSetToVariables';
 
@@ -45,8 +46,8 @@ const getDataSourceMock = jest.fn();
 
 const fakeDsMock: DataSourceApi = {
   name: 'fake-std',
-  type: 'fake-std',
-  getRef: () => ({ type: 'fake-std', uid: 'fake-std' }),
+  type: 'fake-type',
+  getRef: () => ({ type: 'fake-type', uid: 'fake-uid' }),
   query: () =>
     Promise.resolve({
       data: [],
@@ -74,7 +75,7 @@ const fakeDsMock: DataSourceApi = {
     toDataQuery: (q) => ({ ...q, refId: 'FakeDataSource-refId' }),
   },
   id: 1,
-  uid: 'fake-std',
+  uid: 'fake-uid',
 };
 
 jest.mock('@grafana/runtime', () => ({
@@ -93,14 +94,17 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: ['selected-value'],
       text: ['selected-value-text'],
-      datasource: { uid: 'fake-std', type: 'fake-std' },
+      datasource: { uid: 'fake-uid', type: 'fake-type' },
       query: 'query',
       includeAll: true,
       allowCustomValue: true,
       allValue: 'test-all',
       isMulti: true,
+      staticOptions: [{ label: 'test', value: 'test' }],
+      staticOptionsOrder: 'after',
     });
 
     const set = new SceneVariableSet({
@@ -123,11 +127,12 @@ describe('sceneVariablesSetToVariables', () => {
         ],
       },
       "datasource": {
-        "type": "fake-std",
-        "uid": "fake-std",
+        "type": "fake-type",
+        "uid": "fake-uid",
       },
       "definition": undefined,
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -136,6 +141,13 @@ describe('sceneVariablesSetToVariables', () => {
       "query": "query",
       "refresh": 1,
       "regex": "",
+      "staticOptions": [
+        {
+          "text": "test",
+          "value": "test",
+        },
+      ],
+      "staticOptionsOrder": "after",
       "type": "query",
     }
     `);
@@ -146,15 +158,18 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: ['selected-value'],
       text: ['selected-value-text'],
-      datasource: { uid: 'fake-std', type: 'fake-std' },
+      datasource: { uid: 'fake-uid', type: 'fake-type' },
       query: 'query',
       definition: 'query',
       includeAll: true,
       allValue: 'test-all',
       allowCustomValue: false,
       isMulti: true,
+      staticOptions: [{ label: 'test', value: 'test' }],
+      staticOptionsOrder: 'after',
     });
     const set = new SceneVariableSet({
       variables: [variable],
@@ -176,11 +191,12 @@ describe('sceneVariablesSetToVariables', () => {
         ],
       },
       "datasource": {
-        "type": "fake-std",
-        "uid": "fake-std",
+        "type": "fake-type",
+        "uid": "fake-uid",
       },
       "definition": "query",
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -189,6 +205,13 @@ describe('sceneVariablesSetToVariables', () => {
       "query": "query",
       "refresh": 1,
       "regex": "",
+      "staticOptions": [
+        {
+          "text": "test",
+          "value": "test",
+        },
+      ],
+      "staticOptionsOrder": "after",
       "type": "query",
     }
     `);
@@ -199,9 +222,10 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: ['selected-value'],
       text: ['selected-value-text'],
-      datasource: { uid: 'fake-std', type: 'fake-std' },
+      datasource: { uid: 'fake-uid', type: 'fake-type' },
       query: 'query',
       options: [
         { label: 'test', value: 'test' },
@@ -221,14 +245,15 @@ describe('sceneVariablesSetToVariables', () => {
     expect(result[0].options).toEqual([]);
   });
 
-  it('should handle Query variable when sceneVariablesSetToVariables shoudl keep options', () => {
+  it('should handle Query variable when sceneVariablesSetToVariables should keep options', () => {
     const variable = new QueryVariable({
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: ['test'],
       text: ['test'],
-      datasource: { uid: 'fake-std', type: 'fake-std' },
+      datasource: { uid: 'fake-uid', type: 'fake-type' },
       query: 'query',
       options: [
         { label: 'test', value: 'test' },
@@ -255,6 +280,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: ['selected-ds-1', 'selected-ds-2'],
       text: ['selected-ds-1-text', 'selected-ds-2-text'],
       pluginId: 'fake-std',
@@ -285,6 +311,7 @@ describe('sceneVariablesSetToVariables', () => {
         ],
       },
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -303,6 +330,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: ['test', 'test2'],
       text: ['test', 'test2'],
       query: 'test,test1,test2',
@@ -338,6 +366,7 @@ describe('sceneVariablesSetToVariables', () => {
         ],
       },
       "description": "test-desc",
+      "hide": 3,
       "includeAll": true,
       "label": "test-label",
       "multi": true,
@@ -370,6 +399,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: 'constant value',
       skipUrlSync: true,
     });
@@ -402,6 +432,7 @@ describe('sceneVariablesSetToVariables', () => {
       name: 'test',
       label: 'test-label',
       description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
       value: 'text value',
       skipUrlSync: true,
     });
@@ -419,6 +450,7 @@ describe('sceneVariablesSetToVariables', () => {
         "value": "text value",
       },
       "description": "test-desc",
+      "hide": 3,
       "label": "test-label",
       "name": "test",
       "options": [
@@ -440,6 +472,7 @@ describe('sceneVariablesSetToVariables', () => {
       intervals: ['1m', '2m', '3m', '1h', '1d'],
       value: '1m',
       refresh: VariableRefresh.onDashboardLoad,
+      hide: VariableHide.inControlsMenu,
     });
     const set = new SceneVariableSet({
       variables: [variable],
@@ -457,6 +490,7 @@ describe('sceneVariablesSetToVariables', () => {
         "value": "1m",
       },
       "description": undefined,
+      "hide": 3,
       "label": undefined,
       "name": "",
       "options": [
@@ -499,7 +533,8 @@ describe('sceneVariablesSetToVariables', () => {
       allowCustomValue: true,
       label: 'test-label',
       description: 'test-desc',
-      datasource: { uid: 'fake-std', type: 'fake-std' },
+      hide: VariableHide.inControlsMenu,
+      datasource: { uid: 'fake-uid', type: 'fake-type' },
       filters: [
         {
           key: 'filterTest',
@@ -533,8 +568,8 @@ describe('sceneVariablesSetToVariables', () => {
         },
       ],
       "datasource": {
-        "type": "fake-std",
-        "uid": "fake-std",
+        "type": "fake-type",
+        "uid": "fake-uid",
       },
       "defaultKeys": undefined,
       "description": "test-desc",
@@ -545,6 +580,7 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "test",
         },
       ],
+      "hide": 3,
       "label": "test-label",
       "name": "test",
       "type": "adhoc",
@@ -559,6 +595,7 @@ describe('sceneVariablesSetToVariables', () => {
         allowCustomValue: true,
         label: 'test-label',
         description: 'test-desc',
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-std', type: 'fake-std' },
         originFilters: [
           {
@@ -588,6 +625,7 @@ describe('sceneVariablesSetToVariables', () => {
         "defaultKeys": undefined,
         "description": "test-desc",
         "filters": [],
+        "hide": 3,
         "label": "test-label",
         "name": "test",
         "type": "adhoc",
@@ -601,6 +639,7 @@ describe('sceneVariablesSetToVariables', () => {
         allowCustomValue: true,
         label: 'test-label',
         description: 'test-desc',
+        hide: VariableHide.inControlsMenu,
         datasource: { uid: 'fake-std', type: 'fake-std' },
         originFilters: [
           {
@@ -648,6 +687,7 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test2",
           },
         ],
+        "hide": 3,
         "label": "test-label",
         "name": "test",
         "type": "adhoc",
@@ -662,7 +702,8 @@ describe('sceneVariablesSetToVariables', () => {
       allowCustomValue: true,
       label: 'test-label',
       description: 'test-desc',
-      datasource: { uid: 'fake-std', type: 'fake-std' },
+      hide: VariableHide.inControlsMenu,
+      datasource: { uid: 'fake-uid', type: 'fake-type' },
       defaultKeys: [
         {
           text: 'some',
@@ -710,8 +751,8 @@ describe('sceneVariablesSetToVariables', () => {
         },
       ],
       "datasource": {
-        "type": "fake-std",
-        "uid": "fake-std",
+        "type": "fake-type",
+        "uid": "fake-uid",
       },
       "defaultKeys": [
         {
@@ -735,6 +776,7 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "test",
         },
       ],
+      "hide": 3,
       "label": "test-label",
       "name": "test",
       "type": "adhoc",
@@ -757,7 +799,8 @@ describe('sceneVariablesSetToVariables', () => {
         label: 'test-label',
         description: 'test-desc',
         allowCustomValue: true,
-        datasource: { uid: 'fake-std', type: 'fake-std' },
+        hide: VariableHide.inControlsMenu,
+        datasource: { uid: 'fake-uid', type: 'fake-type' },
         defaultOptions: [
           {
             text: 'Foo',
@@ -784,11 +827,12 @@ describe('sceneVariablesSetToVariables', () => {
           "value": [],
         },
         "datasource": {
-          "type": "fake-std",
-          "uid": "fake-std",
+          "type": "fake-type",
+          "uid": "fake-uid",
         },
         "defaultValue": undefined,
         "description": "test-desc",
+        "hide": 3,
         "label": "test-label",
         "name": "test",
         "options": [
@@ -813,7 +857,8 @@ describe('sceneVariablesSetToVariables', () => {
         name: 'test',
         label: 'test-label',
         description: 'test-desc',
-        datasource: { uid: 'fake-std', type: 'fake-std' },
+        hide: VariableHide.inControlsMenu,
+        datasource: { uid: 'fake-uid', type: 'fake-type' },
         defaultOptions: [
           {
             text: 'Foo',
@@ -833,6 +878,168 @@ describe('sceneVariablesSetToVariables', () => {
     });
   });
 
+  it('should handle SwitchVariable with "true" value', () => {
+    const variable = new SwitchVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: 'true',
+      skipUrlSync: true,
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "true",
+    "value": "true",
+  },
+  "description": "test-desc",
+  "hide": 3,
+  "label": "test-label",
+  "name": "test",
+  "options": [
+    {
+      "text": "true",
+      "value": "true",
+    },
+    {
+      "text": "false",
+      "value": "false",
+    },
+  ],
+  "skipUrlSync": true,
+  "type": "switch",
+}
+`);
+  });
+
+  it('should handle SwitchVariable with "false" value', () => {
+    const variable = new SwitchVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: 'false',
+      skipUrlSync: false,
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "false",
+    "value": "false",
+  },
+  "description": "test-desc",
+  "hide": 3,
+  "label": "test-label",
+  "name": "test",
+  "options": [
+    {
+      "text": "true",
+      "value": "true",
+    },
+    {
+      "text": "false",
+      "value": "false",
+    },
+  ],
+  "type": "switch",
+}
+`);
+  });
+
+  it('should handle SwitchVariable with custom values', () => {
+    const variable = new SwitchVariable({
+      name: 'test',
+      label: 'test-label',
+      description: 'test-desc',
+      hide: VariableHide.inControlsMenu,
+      value: 'on',
+      enabledValue: 'on',
+      disabledValue: 'off',
+      skipUrlSync: false,
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "on",
+    "value": "on",
+  },
+  "description": "test-desc",
+  "hide": 3,
+  "label": "test-label",
+  "name": "test",
+  "options": [
+    {
+      "text": "on",
+      "value": "on",
+    },
+    {
+      "text": "off",
+      "value": "off",
+    },
+  ],
+  "type": "switch",
+}
+`);
+  });
+
+  it('should handle SwitchVariable with minimal configuration', () => {
+    const variable = new SwitchVariable({
+      name: 'minimal',
+      value: 'true',
+    });
+    const set = new SceneVariableSet({
+      variables: [variable],
+    });
+
+    const result = sceneVariablesSetToVariables(set);
+
+    expect(result).toHaveLength(1);
+    expect(result[0]).toMatchInlineSnapshot(`
+{
+  "current": {
+    "text": "true",
+    "value": "true",
+  },
+  "description": undefined,
+  "label": undefined,
+  "name": "minimal",
+  "options": [
+    {
+      "text": "true",
+      "value": "true",
+    },
+    {
+      "text": "false",
+      "value": "false",
+    },
+  ],
+  "type": "switch",
+}
+`);
+  });
+
   describe('sceneVariablesSetToSchemaV2Variables', () => {
     it('should handle QueryVariable', () => {
       const variable = new QueryVariable({
@@ -841,11 +1048,14 @@ describe('sceneVariablesSetToVariables', () => {
         description: 'test-desc',
         value: ['selected-value'],
         text: ['selected-value-text'],
-        datasource: { uid: 'fake-std', type: 'fake-std' },
+        datasource: { uid: 'fake-uid', type: 'fake-type' },
         query: 'query',
         includeAll: true,
         allValue: 'test-all',
         isMulti: true,
+        staticOptions: [{ label: 'test', value: 'test' }],
+        staticOptionsOrder: 'after',
+        hide: VariableHide.inControlsMenu,
       });
 
       const set = new SceneVariableSet({
@@ -856,44 +1066,52 @@ describe('sceneVariablesSetToVariables', () => {
 
       expect(result).toHaveLength(1);
       expect(result[0]).toMatchInlineSnapshot(`
-    {
-      "kind": "QueryVariable",
-      "spec": {
-        "allValue": "test-all",
-        "allowCustomValue": true,
-        "current": {
-          "text": [
-            "selected-value-text",
-          ],
-          "value": [
-            "selected-value",
-          ],
-        },
-        "datasource": {
-          "type": "fake-std",
-          "uid": "fake-std",
-        },
-        "definition": undefined,
-        "description": "test-desc",
-        "hide": "dontHide",
-        "includeAll": true,
-        "label": "test-label",
-        "multi": true,
-        "name": "test",
-        "options": [],
-        "query": {
-          "kind": "fake-std",
+        {
+          "kind": "QueryVariable",
           "spec": {
-            "__legacyStringValue": "query",
+            "allValue": "test-all",
+            "allowCustomValue": true,
+            "current": {
+              "text": [
+                "selected-value-text",
+              ],
+              "value": [
+                "selected-value",
+              ],
+            },
+            "definition": undefined,
+            "description": "test-desc",
+            "hide": "inControlsMenu",
+            "includeAll": true,
+            "label": "test-label",
+            "multi": true,
+            "name": "test",
+            "options": [],
+            "query": {
+              "datasource": {
+                "name": "fake-uid",
+              },
+              "group": "fake-type",
+              "kind": "DataQuery",
+              "spec": {
+                "__legacyStringValue": "query",
+              },
+              "version": "v0",
+            },
+            "refresh": "onDashboardLoad",
+            "regex": "",
+            "skipUrlSync": false,
+            "sort": "disabled",
+            "staticOptions": [
+              {
+                "text": "test",
+                "value": "test",
+              },
+            ],
+            "staticOptionsOrder": "after",
           },
-        },
-        "refresh": "onDashboardLoad",
-        "regex": "",
-        "skipUrlSync": false,
-        "sort": "disabled",
-      },
-    }
-    `);
+        }
+      `);
     });
 
     it('should handle CustomVariable', () => {
@@ -904,6 +1122,7 @@ describe('sceneVariablesSetToVariables', () => {
         value: ['test', 'test2'],
         text: ['test', 'test2'],
         query: 'test,test1,test2',
+        hide: VariableHide.inControlsMenu,
         options: [
           { label: 'test', value: 'test' },
           { label: 'test1', value: 'test1' },
@@ -937,7 +1156,7 @@ describe('sceneVariablesSetToVariables', () => {
           ],
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "includeAll": true,
         "label": "test-label",
         "multi": true,
@@ -977,6 +1196,7 @@ describe('sceneVariablesSetToVariables', () => {
         includeAll: true,
         allValue: 'test-all',
         isMulti: true,
+        hide: VariableHide.inControlsMenu,
       });
       const set = new SceneVariableSet({
         variables: [variable],
@@ -1002,7 +1222,7 @@ describe('sceneVariablesSetToVariables', () => {
           ],
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "includeAll": true,
         "label": "test-label",
         "multi": true,
@@ -1023,6 +1243,7 @@ describe('sceneVariablesSetToVariables', () => {
         label: 'test-label',
         description: 'test-desc',
         value: 'constant value',
+        hide: VariableHide.inControlsMenu,
         skipUrlSync: true,
       });
       const set = new SceneVariableSet({
@@ -1041,7 +1262,7 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "constant value",
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
         "query": "constant value",
@@ -1057,6 +1278,7 @@ describe('sceneVariablesSetToVariables', () => {
         label: 'test-label',
         description: 'test-desc',
         value: 'text value',
+        hide: VariableHide.inControlsMenu,
         skipUrlSync: true,
       });
       const set = new SceneVariableSet({
@@ -1075,7 +1297,7 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "text value",
         },
         "description": "test-desc",
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
         "query": "text value",
@@ -1089,6 +1311,7 @@ describe('sceneVariablesSetToVariables', () => {
       const variable = new IntervalVariable({
         intervals: ['1m', '2m', '3m', '1h', '1d'],
         value: '1m',
+        hide: VariableHide.inControlsMenu,
         refresh: VariableRefresh.onDashboardLoad,
       });
       const set = new SceneVariableSet({
@@ -1109,7 +1332,7 @@ describe('sceneVariablesSetToVariables', () => {
           "value": "1m",
         },
         "description": undefined,
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": undefined,
         "name": "",
         "options": [
@@ -1152,7 +1375,8 @@ describe('sceneVariablesSetToVariables', () => {
         name: 'test',
         label: 'test-label',
         description: 'test-desc',
-        datasource: { uid: 'fake-std', type: 'fake-std' },
+        hide: VariableHide.inControlsMenu,
+        datasource: { uid: 'fake-uid', type: 'fake-type' },
         filters: [
           {
             key: 'filterTest',
@@ -1177,6 +1401,10 @@ describe('sceneVariablesSetToVariables', () => {
       expect(result).toHaveLength(1);
       expect(result[0]).toMatchInlineSnapshot(`
     {
+      "datasource": {
+        "name": "fake-uid",
+      },
+      "group": "fake-type",
       "kind": "AdhocVariable",
       "spec": {
         "allowCustomValue": true,
@@ -1187,10 +1415,6 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test",
           },
         ],
-        "datasource": {
-          "type": "fake-std",
-          "uid": "fake-std",
-        },
         "defaultKeys": [],
         "description": "test-desc",
         "filters": [
@@ -1200,7 +1424,7 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test",
           },
         ],
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
         "skipUrlSync": false,
@@ -1214,7 +1438,8 @@ describe('sceneVariablesSetToVariables', () => {
         name: 'test',
         label: 'test-label',
         description: 'test-desc',
-        datasource: { uid: 'fake-std', type: 'fake-std' },
+        hide: VariableHide.inControlsMenu,
+        datasource: { uid: 'fake-uid', type: 'fake-type' },
         defaultKeys: [
           {
             text: 'some',
@@ -1253,6 +1478,10 @@ describe('sceneVariablesSetToVariables', () => {
       expect(result).toHaveLength(1);
       expect(result[0]).toMatchInlineSnapshot(`
     {
+      "datasource": {
+        "name": "fake-uid",
+      },
+      "group": "fake-type",
       "kind": "AdhocVariable",
       "spec": {
         "allowCustomValue": true,
@@ -1263,10 +1492,6 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test",
           },
         ],
-        "datasource": {
-          "type": "fake-std",
-          "uid": "fake-std",
-        },
         "defaultKeys": [
           {
             "text": "some",
@@ -1289,7 +1514,7 @@ describe('sceneVariablesSetToVariables', () => {
             "value": "test",
           },
         ],
-        "hide": "dontHide",
+        "hide": "inControlsMenu",
         "label": "test-label",
         "name": "test",
         "skipUrlSync": false,
@@ -1312,7 +1537,8 @@ describe('sceneVariablesSetToVariables', () => {
           name: 'test',
           label: 'test-label',
           description: 'test-desc',
-          datasource: { uid: 'fake-std', type: 'fake-std' },
+          hide: VariableHide.inControlsMenu,
+          datasource: { uid: 'fake-uid', type: 'fake-type' },
           defaultOptions: [
             {
               text: 'Foo',
@@ -1333,19 +1559,19 @@ describe('sceneVariablesSetToVariables', () => {
         expect(result).toHaveLength(1);
         expect(result[0]).toMatchInlineSnapshot(`
       {
+        "datasource": {
+          "name": "fake-uid",
+        },
+        "group": "fake-type",
         "kind": "GroupByVariable",
         "spec": {
           "current": {
             "text": [],
             "value": [],
           },
-          "datasource": {
-            "type": "fake-std",
-            "uid": "fake-std",
-          },
           "defaultValue": undefined,
           "description": "test-desc",
-          "hide": "dontHide",
+          "hide": "inControlsMenu",
           "label": "test-label",
           "multi": true,
           "name": "test",
@@ -1372,7 +1598,8 @@ describe('sceneVariablesSetToVariables', () => {
           name: 'test',
           label: 'test-label',
           description: 'test-desc',
-          datasource: { uid: 'fake-std', type: 'fake-std' },
+          hide: VariableHide.inControlsMenu,
+          datasource: { uid: 'fake-uid', type: 'fake-type' },
           defaultOptions: [
             {
               text: 'Foo',
@@ -1391,5 +1618,100 @@ describe('sceneVariablesSetToVariables', () => {
         expect(() => sceneVariablesSetToSchemaV2Variables(set)).toThrow('Unsupported variable type');
       });
     });
+
+    it('should handle SwitchVariable with true value', () => {
+      const variable = new SwitchVariable({
+        name: 'test',
+        label: 'test-label',
+        description: 'test-desc',
+        hide: VariableHide.inControlsMenu,
+        value: 'true',
+        skipUrlSync: true,
+      });
+      const set = new SceneVariableSet({
+        variables: [variable],
+      });
+
+      const result = sceneVariablesSetToSchemaV2Variables(set);
+
+      expect(result).toHaveLength(1);
+      expect(result[0]).toMatchInlineSnapshot(`
+{
+  "kind": "SwitchVariable",
+  "spec": {
+    "current": "true",
+    "description": "test-desc",
+    "disabledValue": "false",
+    "enabledValue": "true",
+    "hide": "inControlsMenu",
+    "label": "test-label",
+    "name": "test",
+    "skipUrlSync": true,
+  },
+}
+`);
+    });
+
+    it('should handle SwitchVariable with false value', () => {
+      const variable = new SwitchVariable({
+        name: 'test',
+        label: 'test-label',
+        description: 'test-desc',
+        hide: VariableHide.inControlsMenu,
+        value: 'false',
+        skipUrlSync: false,
+      });
+      const set = new SceneVariableSet({
+        variables: [variable],
+      });
+
+      const result = sceneVariablesSetToSchemaV2Variables(set);
+
+      expect(result).toHaveLength(1);
+      expect(result[0]).toMatchInlineSnapshot(`
+{
+  "kind": "SwitchVariable",
+  "spec": {
+    "current": "false",
+    "description": "test-desc",
+    "disabledValue": "false",
+    "enabledValue": "true",
+    "hide": "inControlsMenu",
+    "label": "test-label",
+    "name": "test",
+    "skipUrlSync": false,
+  },
+}
+`);
+    });
+
+    it('should handle SwitchVariable with minimal configuration', () => {
+      const variable = new SwitchVariable({
+        name: 'minimal',
+        value: 'true',
+      });
+      const set = new SceneVariableSet({
+        variables: [variable],
+      });
+
+      const result = sceneVariablesSetToSchemaV2Variables(set);
+
+      expect(result).toHaveLength(1);
+      expect(result[0]).toMatchInlineSnapshot(`
+{
+  "kind": "SwitchVariable",
+  "spec": {
+    "current": "true",
+    "description": undefined,
+    "disabledValue": "false",
+    "enabledValue": "true",
+    "hide": "dontHide",
+    "label": undefined,
+    "name": "minimal",
+    "skipUrlSync": false,
+  },
+}
+`);
+    });
   });
 });
