@@ -43,8 +43,15 @@ export interface ChangeSizePayload {
   exploreId: string;
   width: number;
 }
+
 export const changeSizeAction = createAction<ChangeSizePayload>('explore/changeSize');
 
+interface ChangeCompactModePayload {
+  exploreId: string;
+  compact: boolean;
+}
+export const changeCompactModeAction = createAction<ChangeCompactModePayload>('explore/changeCompactMode');
+
 /**
  * Tracks the state of explore panels that gets synced with the url.
  */
@@ -52,7 +59,9 @@ interface ChangePanelsState {
   exploreId: string;
   panelsState: ExplorePanelsState;
 }
+
 export const changePanelsStateAction = createAction<ChangePanelsState>('explore/changePanels');
+
 export function changePanelState(
   exploreId: string,
   panel: PreferredVisualisationType,
@@ -83,10 +92,18 @@ interface ChangeCorrelationHelperData {
   exploreId: string;
   correlationEditorHelperData?: ExploreCorrelationHelperData;
 }
+
 export const changeCorrelationHelperData = createAction<ChangeCorrelationHelperData>(
   'explore/changeCorrelationHelperData'
 );
 
+export interface UpdateQueryLibraryRefPayload {
+  exploreId: string;
+  queryLibraryRef?: string;
+}
+
+export const updateQueryLibraryRefAction = createAction<UpdateQueryLibraryRefPayload>('explore/updateQueryLibraryRef');
+
 /**
  * Initialize Explore state with state from the URL and the React component.
  * Call this only on components for with the Explore state has not been initialized.
@@ -97,19 +114,24 @@ interface InitializeExplorePayload {
   range: TimeRange;
   history: HistoryItem[];
   datasourceInstance?: DataSourceApi;
+  compact: boolean;
   eventBridge: EventBusExtended;
+  queryLibraryRef?: string;
 }
+
 const initializeExploreAction = createAction<InitializeExplorePayload>('explore/initializeExploreAction');
 
 export interface SetUrlReplacedPayload {
   exploreId: string;
 }
+
 export const setUrlReplacedAction = createAction<SetUrlReplacedPayload>('explore/setUrlReplaced');
 
 export interface SaveCorrelationsPayload {
   exploreId: string;
   correlations: CorrelationData[];
 }
+
 export const saveCorrelationsAction = createAction<SaveCorrelationsPayload>('explore/saveCorrelationsAction');
 
 /**
@@ -120,6 +142,10 @@ export function changeSize(exploreId: string, { width }: { width: number }): Pay
   return changeSizeAction({ exploreId, width });
 }
 
+export function changeCompactMode(exploreId: string, compact: boolean): PayloadAction<ChangeCompactModePayload> {
+  return changeCompactModeAction({ exploreId, compact });
+}
+
 export interface InitializeExploreOptions {
   exploreId: string;
   datasource: DataSourceRef | string | undefined;
@@ -129,7 +155,10 @@ export interface InitializeExploreOptions {
   correlationHelperData?: ExploreCorrelationHelperData;
   position?: number;
   eventBridge: EventBusExtended;
+  queryLibraryRef?: string;
+  compact: boolean;
 }
+
 /**
  * Initialize Explore state with state from the URL and the React component.
  * Call this only on components for with the Explore state has not been initialized.
@@ -147,8 +176,10 @@ export const initializeExplore = createAsyncThunk(
       queries,
       range,
       panelsState,
+      compact,
       correlationHelperData,
       eventBridge,
+      queryLibraryRef,
     }: InitializeExploreOptions,
     { dispatch, getState, fulfillWithValue }
   ) => {
@@ -169,7 +200,9 @@ export const initializeExplore = createAsyncThunk(
         range: getRange(range, getTimeZone(getState().user)),
         datasourceInstance: instance,
         history,
+        compact,
         eventBridge,
+        queryLibraryRef,
       })
     );
     if (panelsState !== undefined) {
@@ -214,10 +247,15 @@ export const paneReducer = (state: ExploreItemState = makeExplorePaneState(), ac
   state = timeReducer(state, action);
 
   if (changeSizeAction.match(action)) {
-    const containerWidth = action.payload.width;
+    const containerWidth = Math.floor(action.payload.width);
     return { ...state, containerWidth };
   }
 
+  if (changeCompactModeAction.match(action)) {
+    const compact = action.payload.compact;
+    return { ...state, compact };
+  }
+
   if (changePanelsStateAction.match(action)) {
     const { panelsState } = action.payload;
     return { ...state, panelsState };
@@ -235,8 +273,15 @@ export const paneReducer = (state: ExploreItemState = makeExplorePaneState(), ac
     };
   }
 
+  if (updateQueryLibraryRefAction.match(action)) {
+    return {
+      ...state,
+      queryLibraryRef: action.payload.queryLibraryRef,
+    };
+  }
+
   if (initializeExploreAction.match(action)) {
-    const { queries, range, datasourceInstance, history, eventBridge } = action.payload;
+    const { queries, range, datasourceInstance, history, eventBridge, compact, queryLibraryRef } = action.payload;
 
     return {
       ...state,
@@ -250,6 +295,8 @@ export const paneReducer = (state: ExploreItemState = makeExplorePaneState(), ac
       queryResponse: createEmptyQueryResponse(),
       cache: [],
       correlations: [],
+      queryLibraryRef,
+      compact,
     };
   }
 
