@@ -9,6 +9,7 @@ import {
   CoreApp,
   DataFrame,
   LogRowContextOptions,
+  TimeRange,
 } from '@grafana/data';
 import { Trans, t } from '@grafana/i18n';
 import { config } from '@grafana/runtime';
@@ -61,6 +62,7 @@ export interface Props {
   scrollIntoView?: (element: HTMLElement) => void;
   isFilterLabelActive?: (key: string, value: string, refId?: string) => Promise<boolean>;
   pinnedLogs?: string[];
+  timeRange: TimeRange;
   /**
    * If false or undefined, the `contain:strict` css property will be added to the wrapping `<table>` for performance reasons.
    * Any overflowing content will be clipped at the table boundary.
@@ -328,3 +330,4 @@ export const LogRows = memo(
     );
   }
 );
+LogRows.displayName = 'LogRows';
