@@ -29,7 +29,7 @@ export const PlaylistPage = () => {
       return;
     }
     deletePlaylist({
-      name: playlistToDelete.metadata.name ?? '',
+      name: playlistToDelete.metadata?.name ?? '',
     }).finally(() => {
       setPlaylistToDelete(undefined);
     });
@@ -84,10 +84,10 @@ export const PlaylistPage = () => {
             )}
             {playlistToDelete && (
               <ConfirmModal
-                title={playlistToDelete.spec.title}
+                title={playlistToDelete.spec?.title ?? ''}
                 confirmText={t('playlist-page.delete-modal.confirm-text', 'Delete')}
                 body={t('playlist-page.delete-modal.body', 'Are you sure you want to delete {{name}} playlist?', {
-                  name: playlistToDelete.spec.title,
+                  name: playlistToDelete.spec?.title,
                 })}
                 onConfirm={onDeletePlaylist}
                 isOpen={Boolean(playlistToDelete)}
