@@ -12,7 +12,6 @@ import { config } from '@grafana/runtime';
 import { createLogMock } from './logs/testUtils';
 import {
   assertConfigureIsValid,
-  assertLinkPathIsValid,
   assertStringProps,
   isAddedComponentMetaInfoMissing,
   isAddedLinkMetaInfoMissing,
@@ -25,48 +24,6 @@ import {
 } from './validators';
 
 describe('Plugin Extension Validators', () => {
-  describe('assertLinkPathIsValid()', () => {
-    it('should not throw an error if the link path is valid', () => {
-      expect(() => {
-        const pluginId = 'myorg-b-app';
-        const extension = {
-          path: `/a/${pluginId}/overview`,
-          title: 'My Plugin',
-          description: 'My Plugin Description',
-          extensionPointId: '...',
-        };
-
-        assertLinkPathIsValid(pluginId, extension.path);
-      }).not.toThrowError();
-    });
-
-    it('should throw an error if the link path is pointing to a different plugin', () => {
-      expect(() => {
-        const extension = {
-          path: `/a/myorg-b-app/overview`,
-          title: 'My Plugin',
-          description: 'My Plugin Description',
-          extensionPointId: '...',
-        };
-
-        assertLinkPathIsValid('another-plugin-app', extension.path);
-      }).toThrowError();
-    });
-
-    it('should throw an error if the link path is not prefixed with "/a/<PLUGIN_ID>"', () => {
-      expect(() => {
-        const extension = {
-          path: `/some-bad-path`,
-          title: 'My Plugin',
-          description: 'My Plugin Description',
-          extensionPointId: '...',
-        };
-
-        assertLinkPathIsValid('myorg-b-app', extension.path);
-      }).toThrowError();
-    });
-  });
-
   describe('assertConfigureIsValid()', () => {
     it('should NOT throw an error if the configure() function is missing', () => {
       expect(() => {
@@ -198,9 +155,8 @@ describe('Plugin Extension Validators', () => {
 
   describe('isExtensionPointIdValid()', () => {
     test.each([
-      // We (for now allow core Grafana extension points to run without a version)
-      ['grafana/extension-point', ''],
-      ['grafana/extension-point', 'grafana'],
+      [PluginExtensionPoints.DashboardPanelMenu, ''],
+      [PluginExtensionPoints.DashboardPanelMenu, 'grafana'],
       ['myorg-extensions-app/extension-point', 'myorg-extensions-app'],
       ['myorg-extensions-app/extension-point/v1', 'myorg-extensions-app'],
       ['plugins/myorg-extensions-app/extension-point/v1', 'myorg-extensions-app'],
@@ -212,11 +168,15 @@ describe('Plugin Extension Validators', () => {
       ['plugins/grafana-oncall-app/alert-group/action', 'grafana-oncall-app'],
       ['plugins/grafana-oncall-app/alert-group/action/v1', 'grafana-oncall-app'],
       ['plugins/grafana-oncall-app/alert-group/action/v1.0.0', 'grafana-oncall-app'],
+      ['grafana/dynamic/nav-landing-page/nav-id-observability/v1', 'grafana'], // this a dynamic (runtime evaluated) extension point id
     ])('should return TRUE if the extension point id is valid ("%s", "%s")', (extensionPointId, pluginId) => {
       expect(
         isExtensionPointIdValid({
           extensionPointId,
           pluginId,
+          isInsidePlugin: pluginId !== 'grafana' && pluginId !== '',
+          isCoreGrafanaPlugin: false,
+          log: createLogMock(),
         })
       ).toBe(true);
     });
@@ -232,14 +192,34 @@ describe('Plugin Extension Validators', () => {
         'extension-point/v1',
         'myorgs-extensions-app',
       ],
+      [
+        // Not exposed to plugins
+        'grafana/not-exposed-extension-point/v1',
+        'grafana',
+      ],
     ])('should return FALSE if the extension point id is invalid ("%s", "%s")', (extensionPointId, pluginId) => {
       expect(
         isExtensionPointIdValid({
           extensionPointId,
           pluginId,
+          isInsidePlugin: pluginId !== 'grafana' && pluginId !== '',
+          isCoreGrafanaPlugin: false,
+          log: createLogMock(),
         })
       ).toBe(false);
     });
+
+    it('should return FALSE true if the extension point id is set by a core plugin', () => {
+      expect(
+        isExtensionPointIdValid({
+          extensionPointId: 'traces',
+          pluginId: 'traces',
+          isInsidePlugin: true,
+          isCoreGrafanaPlugin: true,
+          log: createLogMock(),
+        })
+      ).toBe(true);
+    });
   });
 
   describe('isAddedLinkMetaInfoMissing()', () => {
@@ -357,6 +337,21 @@ describe('Plugin Extension Validators', () => {
       expect(log.warning).toHaveBeenCalledTimes(1);
       expect(jest.mocked(log.warning).mock.calls[0][0]).toMatch('"description" doesn\'t match');
     });
+
+    it('should return FALSE with links with the same title but different targets', () => {
+      const log = createLogMock();
+      config.apps[pluginId].extensions.addedLinks.push(extensionConfig);
+      const extensionConfig2 = {
+        ...extensionConfig,
+        targets: [PluginExtensionPoints.ExploreToolbarAction],
+      };
+      config.apps[pluginId].extensions.addedLinks.push(extensionConfig2);
+
+      const returnValue = isAddedLinkMetaInfoMissing(pluginId, extensionConfig2, log);
+
+      expect(returnValue).toBe(false);
+      expect(log.error).toHaveBeenCalledTimes(0);
+    });
   });
 
   describe('isAddedComponentMetaInfoMissing()', () => {
@@ -474,6 +469,21 @@ describe('Plugin Extension Validators', () => {
       expect(log.warning).toHaveBeenCalledTimes(1);
       expect(jest.mocked(log.warning).mock.calls[0][0]).toMatch('"description" doesn\'t match');
     });
+
+    it('should return FALSE with components with the same title but different targets', () => {
+      const log = createLogMock();
+      config.apps[pluginId].extensions.addedComponents.push(extensionConfig);
+      const extensionConfig2 = {
+        ...extensionConfig,
+        targets: [PluginExtensionPoints.ExploreToolbarAction],
+      };
+      config.apps[pluginId].extensions.addedComponents.push(extensionConfig2);
+
+      const returnValue = isAddedComponentMetaInfoMissing(pluginId, extensionConfig2, log);
+
+      expect(returnValue).toBe(false);
+      expect(log.error).toHaveBeenCalledTimes(0);
+    });
   });
 
   describe('isExposedComponentMetaInfoMissing()', () => {
@@ -592,6 +602,21 @@ describe('Plugin Extension Validators', () => {
       expect(log.warning).toHaveBeenCalledTimes(1);
       expect(jest.mocked(log.warning).mock.calls[0][0]).toMatch('"description" doesn\'t match');
     });
+
+    it('should return FALSE with components with the same title but different targets', () => {
+      const log = createLogMock();
+      config.apps[pluginId].extensions.exposedComponents.push(exposedComponentConfig);
+      const exposedComponentConfig2 = {
+        ...exposedComponentConfig,
+        targets: [PluginExtensionPoints.ExploreToolbarAction],
+      };
+      config.apps[pluginId].extensions.exposedComponents.push(exposedComponentConfig2);
+
+      const returnValue = isExposedComponentMetaInfoMissing(pluginId, exposedComponentConfig2, log);
+
+      expect(returnValue).toBe(false);
+      expect(log.error).toHaveBeenCalledTimes(0);
+    });
   });
 
   describe('isExposedComponentDependencyMissing()', () => {
