@@ -1,5 +1,4 @@
-import { ActionModel, Field, InterpolateFunction, LinkModel } from '@grafana/data';
-import { DataFrame } from '@grafana/data/';
+import { DataFrame, ActionModel, Field, InterpolateFunction, LinkModel } from '@grafana/data';
 import { getActions } from 'app/features/actions/utils';
 
 export const getDataLinks = (field: Field, rowIdx: number) => {
@@ -23,28 +22,38 @@ export const getDataLinks = (field: Field, rowIdx: number) => {
   return links;
 };
 
-export const getAllFrameActions = (dataFrame: DataFrame) => {};
-
 export const getFieldActions = (
   dataFrame: DataFrame,
   field: Field,
   replaceVars: InterpolateFunction,
-  rowIndex: number
+  rowIndex: number,
+  visualizationType?: string
 ) => {
   const actions: Array<ActionModel<Field>> = [];
-  const actionLookup = new Set<string>();
 
-  const actionsModel = getActions(dataFrame, field, field.state!.scopedVars!, replaceVars, field.config.actions ?? [], {
-    valueRowIndex: rowIndex,
-  });
+  if (field.state?.scopedVars) {
+    const actionLookup = new Set<string>();
 
-  actionsModel.forEach((action) => {
-    const key = `${action.title}`;
-    if (!actionLookup.has(key)) {
-      actions.push(action);
-      actionLookup.add(key);
-    }
-  });
+    const actionsModel = getActions(
+      dataFrame,
+      field,
+      field.state.scopedVars,
+      replaceVars,
+      field.config.actions ?? [],
+      {
+        valueRowIndex: rowIndex,
+      },
+      visualizationType
+    );
+
+    actionsModel.forEach((action) => {
+      const key = `${action.title}`;
+      if (!actionLookup.has(key)) {
+        actions.push(action);
+        actionLookup.add(key);
+      }
+    });
+  }
 
   return actions;
 };
